<?php

declare(strict_types=1);

namespace Dedi\SyliusStockHistoryPlugin\Resolver;

use Dedi\SyliusStockHistoryPlugin\Context\InventoryLogContextInterface;
use Dedi\SyliusStockHistoryPlugin\Context\InventoryLogContextRegistryInterface;
use Dedi\SyliusStockHistoryPlugin\Enum\InventoryLogEntryType;
use Symfony\Component\HttpFoundation\RequestStack;

class InventoryLogEntryContextResolver implements InventoryLogEntryContextResolverInterface
{
    public function __construct(
        private readonly RequestStack $requestStack,
        private readonly InventoryLogContextRegistryInterface $inventoryLogContextRegistry,
    ) {
    }

    public function resolve(): InventoryLogContextInterface
    {
        $request = $this->requestStack->getCurrentRequest();

        if (null === $request) {
            return $this->inventoryLogContextRegistry->get(InventoryLogEntryType::DEFAULT->value);
        }

        $route = $request->attributes->get('_route');

        return $this->inventoryLogContextRegistry->getContextForRoute($route);
    }
}
