<?php

declare(strict_types=1);

namespace Dedi\SyliusStockHistoryPlugin\Resolver\Order;

use Sylius\Component\Core\Model\OrderInterface;

class CompositeOrderResolver implements InventoryLogOrderResolverInterface
{
    public function __construct(
        private readonly iterable $resolvers,
    ) {
    }

    public function resolve(string $type): ?OrderInterface
    {
        foreach ($this->resolvers as $resolver) {
            if ($resolver->supports($type)) {
                return $resolver->resolve($type);
            }
        }

        return null;
    }

    public function supports(string $type): bool
    {
        foreach ($this->resolvers as $resolver) {
            if ($resolver->supports($type)) {
                return true;
            }
        }

        return false;
    }
}
